/**
 * Converts a hexadecimal color string to an RGBA color array.
 *
 * @param {string} hex - The hexadecimal color string to convert.
 * @param {Object} options - The options object.
 * @param {number} [options.fixed=3] - The number of decimal places to fix the alpha value to.
 * @param {number[]} [options.supportedLengths=[3, 4, 6, 8]] - The supported lengths of the hexadecimal color string.
 *
 * @returns {number[]} - An array containing the red, green, blue, and alpha values of the color, with red, green, and blue in the range 0 to 255 and alpha in the range 0 to 1.
 * @throws {Error} - If the input string is not a valid hexadecimal color string.
 *
 * @example
 * hexToRgba('#fff');  // returns [255, 255, 255, 1]
 * hexToRgba('#fffa'); // returns [255, 255, 255, 0.667]
 * hexToRgba('#ffffff'); // returns [255, 255, 255, 1]
 * hexToRgba('#ffffffbc'); // returns [255, 255, 255, 0.737]
 * hexToRgba('#f00'); // returns [255, 0, 0, 1]
 * hexToRgba('#ff0000'); // returns [255, 0, 0, 1]
 * hexToRgba('#ff0000ff'); // returns [255, 0, 0, 1]
 *
 * @author chatGPT
*/
export declare function hexToRgba(hex: string, options?: {
    fixed?: number;
    supportedLengths?: Array<number>;
}): [number, number, number, number];
export declare function rgbaToHex(rgba: [number, number, number, number], options: {
    fixed?: number;
    lengthType?: 4 | 8;
    addHash?: boolean;
}): string;
